GMMVI: Gaussian Mixture Model Variational Inference
===================================================

A framework for optimizing Gaussian mixture models for variational inference.
Please refer to the `online documentation <https://gmmvi.rtfd.io>`_ for details.
